==> goobox_3.3.1.orig.tar.xz: goobox-3.3.1/src/goo-application-actions-callbacks.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Goo
 *
 *  Copyright (C) 2013 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef GOO_APPLICATION_ACTIONS_CALLBACKS_H
#define GOO_APPLICATION_ACTIONS_CALLBACKS_H

#include <gtk/gtk.h>
#include "glib-utils.h"

void update_actions_sensitivity (GApplication *application);

DEF_ACTION_CALLBACK (goo_application_activate_about)
DEF_ACTION_CALLBACK (goo_application_activate_help)
DEF_ACTION_CALLBACK (goo_application_activate_play_all)
DEF_ACTION_CALLBACK (goo_application_activate_preferences)
DEF_ACTION_CALLBACK (goo_application_activate_quit)
DEF_ACTION_CALLBACK (goo_application_activate_repeat)
DEF_ACTION_CALLBACK (goo_application_activate_shuffle)

#endif /* GOO_APPLICATION_ACTIONS_CALLBACKS_H */

==> goobox_3.6.0.orig.tar.xz: goobox-3.6.0/src/goo-application-actions-callbacks.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Goo
 *
 *  Copyright (C) 2013 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GOO_APPLICATION_ACTIONS_CALLBACKS_H
#define GOO_APPLICATION_ACTIONS_CALLBACKS_H

#include <gtk/gtk.h>
#include "glib-utils.h"

void update_actions_sensitivity (GApplication *application);

DEF_ACTION_CALLBACK (goo_application_activate_about)
DEF_ACTION_CALLBACK (goo_application_activate_help)
DEF_ACTION_CALLBACK (goo_application_activate_play_all)
DEF_ACTION_CALLBACK (goo_application_activate_preferences)
DEF_ACTION_CALLBACK (goo_application_activate_quit)
DEF_ACTION_CALLBACK (goo_application_activate_repeat)
DEF_ACTION_CALLBACK (goo_application_activate_shuffle)
DEF_ACTION_CALLBACK (goo_application_activate_pause)
DEF_ACTION_CALLBACK (goo_application_activate_play)
DEF_ACTION_CALLBACK (goo_application_activate_play_next)

#endif /* GOO_APPLICATION_ACTIONS_CALLBACKS_H */
